@@ -13,14 +13,19 @@
 #' wcde_location(country_code = c(-11, 44))
 #' wcde_location(country_code = c(100, 44))
 #' wcde_location(country_code = 3)
-wcde_location <- function(country_code){
+wcde_location <- function(country_code,
+                          version = c("wcde-v3", "wcde-v2", "wcde-v1")){
+  version <- match.arg(version)
   v <- wcde::wic_locations %>%
+    tidyr::pivot_longer(dplyr::contains("wcde"), names_to = "vv", values_to = "avail") %>%
+    dplyr::filter(vv == version,
+                  avail) %>%
     tidyr::drop_na(isono) %>%
     dplyr::pull(isono)
   x <- sum(!country_code %in% v) == 0
   if(!x){
     ok <- which(country_code %in% v)
-    message(paste0("country code ", country_code[-ok], " not in Wittgenstein Human Capital Data Explorer"))
+    message(paste0("country code ", country_code[-ok], " not in Wittgenstein Human Capital Data Explorer for version provided"))
   }
   return(x)
 }
